===========
Aggregation
===========

.. currentmodule:: polars
.. autosummary::
   :toctree: api/

    Expr.agg_groups
    Expr.all
    Expr.any
    Expr.approx_n_unique
    Expr.arg_max
    Expr.arg_min
    Expr.count
    Expr.first
    Expr.implode
    Expr.last
    Expr.len
    Expr.max
    Expr.mean
    Expr.median
    Expr.min
    Expr.n_unique
    Expr.nan_max
    Expr.nan_min
    Expr.null_count
    Expr.product
    Expr.quantile
    Expr.std
    Expr.sum
    Expr.var
